//+------------------------------------------------------------------+
//|                                            one-button-click.mq4  |
//|                                            Trade Smart FX Tools  |
//|                                 https://tradesmartfxtools.online |
//+------------------------------------------------------------------+
#property strict

// Parameters
input int    TP_Pips = 20;          // Take Profit in Pips
input int    SL_Pips = 10;          // Stop Loss in Pips
input double LotSize = 0.1;         // Lot Size

// Constants for button IDs
#define BUTTON_BUY "BuyButton"
#define BUTTON_SELL "SellButton"

// Label Parameters
string labelName = "tradesmartfxtools.online";
string labelText = "EA by tradesmartfxtools.online";
string buyProfitLabelName = "OverallBuyProfitLabel";
string sellProfitLabelName = "OverallSellProfitLabel";
string updatedLabelName = "updated_version_label";
string updatedLabelText = "Updated version available at tradesmartfxtools.online";

int labelFontSize = 16;
int updatedLabelFontSize = 14; // Font size for updated version text
color labelColor = Yellow;
color profitLabelColor = White;
color lossLabelColor = White;
color updatedLabelColor = White; // Updated version label color
int spaceFromBottom = 50;
int updatedSpaceFromBottom = 20; // Position for updated version label

//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
   // Create styled BUY and SELL buttons
   CreateStyledButton(BUTTON_BUY, "BUY", 0, 20, 100, 30);
   CreateStyledButton(BUTTON_SELL, "SELL", 0, 130, 100, 30);

   // Initial call to create or update labels on the chart with zero profit and zero spread
   createOrUpdateLabels(0.0, 0.0);
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   // Delete buttons on deinitialization
   DeleteButton(BUTTON_BUY);
   DeleteButton(BUTTON_SELL);

   // Delete labels on deinitialization
   ObjectDelete(0, labelName);
   ObjectDelete(0, updatedLabelName);
   ObjectDelete(0, buyProfitLabelName);
   ObjectDelete(0, sellProfitLabelName);
  }
//+------------------------------------------------------------------+
//| Expert chart event function                                      |
//+------------------------------------------------------------------+
void OnChartEvent(const int id,         // Event identifier
                  const long &lparam,   // Parameter of type long event
                  const double &dparam, // Parameter of type double event
                  const string &sparam) // Parameter of type string event
  {
   // Check if a button is clicked
   if(id == CHARTEVENT_OBJECT_CLICK)
     {
      if(sparam == BUTTON_BUY)
         ExecuteTrade(ORDER_TYPE_BUY);
      else if(sparam == BUTTON_SELL)
         ExecuteTrade(ORDER_TYPE_SELL);
     }
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
   double totalBuyProfit = 0.0;
   double totalSellProfit = 0.0;
   int buyCount = 0;
   int sellCount = 0;
   double spread = MarketInfo(Symbol(), MODE_SPREAD) * Point;

   // Calculate total buy and sell profits and counts
   for(int i = OrdersTotal() - 1; i >= 0; i--)
     {
      if(OrderSelect(i, SELECT_BY_POS, MODE_TRADES) && OrderSymbol() == _Symbol)
        {
         if(OrderType() == OP_BUY)
           {
            totalBuyProfit += OrderProfit();
            buyCount++;
           }
         else if(OrderType() == OP_SELL)
           {
            totalSellProfit += OrderProfit();
            sellCount++;
           }
        }
     }

   // Update all labels with current profit values and trade counts
   createOrUpdateLabels(totalBuyProfit, totalSellProfit);
  }
//+------------------------------------------------------------------+
//| Function to create a styled button                               |
//+------------------------------------------------------------------+
void CreateStyledButton(string name, string label, int sub_window, int x_distance, int width, int height)
  {
   // Create the button object
   if(!ObjectCreate(0, name, OBJ_BUTTON, sub_window, 0, 0))
     {
      Print("Error creating button ", name);
      return;
     }

   // Set button properties for positioning and appearance
   ObjectSetInteger(0, name, OBJPROP_CORNER, CORNER_LEFT_UPPER);  // Position in the upper-left corner
   ObjectSetInteger(0, name, OBJPROP_XDISTANCE, x_distance);      // X distance from left edge
   ObjectSetInteger(0, name, OBJPROP_YDISTANCE, 20);              // Y distance from top
   ObjectSetInteger(0, name, OBJPROP_XSIZE, width);               // Button width
   ObjectSetInteger(0, name, OBJPROP_YSIZE, height);              // Button height
   ObjectSetString(0, name, OBJPROP_TEXT, label);                 // Button label

   // Set background, text color, and border colors
   ObjectSetInteger(0, name, OBJPROP_BGCOLOR, clrGreen);          // Button background color (green)
   ObjectSetInteger(0, name, OBJPROP_BORDER_TYPE, BORDER_RAISED); // Raised border
   ObjectSetInteger(0, name, OBJPROP_STYLE, STYLE_SOLID);         // Solid border
   ObjectSetInteger(0, name, OBJPROP_COLOR, clrWhite);            // Button text color (white)
   ObjectSetInteger(0, name, OBJPROP_FONTSIZE, 12);               // Font size
  }
//+------------------------------------------------------------------+
//| Function to delete a button                                      |
//+------------------------------------------------------------------+
void DeleteButton(string name)
  {
   ObjectDelete(0, name);
  }
//+------------------------------------------------------------------+
//| Function to execute a trade                                      |
//+------------------------------------------------------------------+
void ExecuteTrade(int trade_type)
  {
   double price = (trade_type == OP_BUY) ? Ask : Bid;

   // Determine pip size based on symbol's digit count
   int digits = SymbolInfoInteger(_Symbol, SYMBOL_DIGITS);
   double pipSize = (digits == 5 || digits == 3) ? Point * 10 : Point;

   // Convert TP and SL in pips to price points
   double sl = (trade_type == OP_BUY) ? price - SL_Pips * pipSize : price + SL_Pips * pipSize;
   double tp = (trade_type == OP_BUY) ? price + TP_Pips * pipSize : price - TP_Pips * pipSize;
   
   int ticket;
   if(trade_type == OP_BUY)
      ticket = OrderSend(Symbol(), OP_BUY, LotSize, Ask, 3, sl, tp, "Buy Order", 0, 0, clrGreen);
   else
      ticket = OrderSend(Symbol(), OP_SELL, LotSize, Bid, 3, sl, tp, "Sell Order", 0, 0, clrRed);
      
   if(ticket < 0)
      Print("Error opening order: ", GetLastError());
   else
      Print("Trade successfully placed. Ticket#: ", ticket);
  }
//+------------------------------------------------------------------+
//| Function to create or update labels                              |
//+------------------------------------------------------------------+
void createOrUpdateLabels(double buyProfit, double sellProfit)
  {
   // Create or update the trademark label (kept in the bottom-left corner)
   if(ObjectFind(0, labelName) == -1)
     {
      ObjectCreate(0, labelName, OBJ_LABEL, 0, 0, 0);
     }
   ObjectSetInteger(0, labelName, OBJPROP_CORNER, CORNER_LEFT_LOWER);
   ObjectSetInteger(0, labelName, OBJPROP_XDISTANCE, 10);
   ObjectSetInteger(0, labelName, OBJPROP_YDISTANCE, spaceFromBottom);
   ObjectSetInteger(0, labelName, OBJPROP_COLOR, labelColor);
   ObjectSetInteger(0, labelName, OBJPROP_FONTSIZE, labelFontSize);
   ObjectSetInteger(0, labelName, OBJPROP_SELECTABLE, false);
   ObjectSetInteger(0, labelName, OBJPROP_SELECTED, false);
   ObjectSetString(0, labelName, OBJPROP_TEXT, labelText);

   // Create or update the updated version label (kept below the trademark label)
   if(ObjectFind(0, updatedLabelName) == -1)
     {
      ObjectCreate(0, updatedLabelName, OBJ_LABEL, 0, 0, 0);
     }
   ObjectSetInteger(0, updatedLabelName, OBJPROP_CORNER, CORNER_LEFT_LOWER);
   ObjectSetInteger(0, updatedLabelName, OBJPROP_XDISTANCE, 10);
   ObjectSetInteger(0, updatedLabelName, OBJPROP_YDISTANCE, updatedSpaceFromBottom);
   ObjectSetInteger(0, updatedLabelName, OBJPROP_COLOR, updatedLabelColor);
   ObjectSetInteger(0, updatedLabelName, OBJPROP_FONTSIZE, updatedLabelFontSize);
   ObjectSetString(0, updatedLabelName, OBJPROP_TEXT, updatedLabelText);

   // Create or update the buy profit label (move to the upper-right corner)
   string buyProfitText = "Overall Buy Profit: " + DoubleToString(buyProfit, 2);
   if(ObjectFind(0, buyProfitLabelName) == -1)
     {
      ObjectCreate(0, buyProfitLabelName, OBJ_LABEL, 0, 0, 0);
     }
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_CORNER, CORNER_RIGHT_UPPER);
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_XDISTANCE, 270);
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_YDISTANCE, 30); // Adjusted Y position
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_COLOR, profitLabelColor);
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_FONTSIZE, labelFontSize);
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_SELECTABLE, false);
   ObjectSetInteger(0, buyProfitLabelName, OBJPROP_SELECTED, false);
   ObjectSetString(0, buyProfitLabelName, OBJPROP_TEXT, buyProfitText);

   // Create or update the sell profit label (move to the upper-right corner)
   string sellProfitText = "Overall Sell Profit: " + DoubleToString(sellProfit, 2);
   if(ObjectFind(0, sellProfitLabelName) == -1)
     {
      ObjectCreate(0, sellProfitLabelName, OBJ_LABEL, 0, 0, 0);
     }
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_CORNER, CORNER_RIGHT_UPPER);
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_XDISTANCE, 270);
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_YDISTANCE, 50); // Adjusted Y position
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_COLOR, lossLabelColor);
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_FONTSIZE, labelFontSize);
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_SELECTABLE, false);
   ObjectSetInteger(0, sellProfitLabelName, OBJPROP_SELECTED, false);
   ObjectSetString(0, sellProfitLabelName, OBJPROP_TEXT, sellProfitText);
  }
//+------------------------------------------------------------------+
